@@ -882,6 +882,53 @@ def rolling_ensembling(X, w_mat_predictors_list, w_mat_target, n=252, s=63,ret=T
             portfolio.loc[slice_s] = portfolio.loc[roll.d] * perf.flatten()
         w_mat = w_mat.fillna(method='ffill').fillna(0.)
         return portfolio, w_mat
+    elif ensembling_model == 'period_min_dd':
+        starting_date = kwargs['starting_date']
+        ending_date = kwargs['ending_date']
+        index_tmp = w_mat_predictors_list[0].index
+        print('length before filtering '+ str(len(index_tmp)))
+        print('min before filtering '+ str(min(index_tmp)))
+        print('max before filtering '+ str(max(index_tmp)))
+        to_time_filter_df = lambda my_df : my_df.iloc[my_df.index >= starting_date].copy()
+        filtered_w_mat_predictors_list = list(map(to_time_filter_df, w_mat_predictors_list))
+        up_time_filter_df = lambda my_df: my_df.iloc[my_df.index <= ending_date].copy()
+        filtered_w_mat_predictors_list = list(map(up_time_filter_df, filtered_w_mat_predictors_list))
+        filtered_index_tmp = filtered_w_mat_predictors_list[0].index
+        print('length after filtering '+ str(len(filtered_index_tmp)))
+        print('min after filtering '+ str(min(filtered_index_tmp)))
+        print('max after filtering '+ str(max(filtered_index_tmp)))
+
+        X_filtered = X_.iloc[X_.index >= starting_date].copy()
+        X_filtered = X_filtered.iloc[X_filtered.index <= ending_date].copy()
+        print('return shape')
+        print(X_filtered.shape)
+        print('number of weights configuration')
+        print(len(w_mat_predictors_list))
+        print('optimizing')
+        optimal_weights = metrics.find_best_perf_weights(X_filtered, filtered_w_mat_predictors_list)
+
+
+        print('optimal weights found')
+
+        print(optimal_weights)
+
+        columns_tmp = w_mat_predictors_list[0].columns
+        to_np = lambda my_df : my_df.values
+        w_mat_predictors_list = list(map(to_np, w_mat_predictors_list))
+        np_mean_weights = None
+        counter = 0
+        for np_weights in w_mat_predictors_list:
+            if np_mean_weights is None :
+                np_mean_weights = optimal_weights[counter]*np_weights
+            else :
+                np_mean_weights = np_mean_weights + optimal_weights[counter]*np_weights
+            counter = counter+1
+
+        print(np_mean_weights.sum(axis=1))
+        #np_mean_weights = np_mean_weights/len(w_mat_predictors_list)
+        w_mat = pd.DataFrame(data = np_mean_weights,index=index_tmp, columns=columns_tmp)
+        portfolio = np.cumprod(np.prod(X_ * w_mat.values + 1, axis=1))
+        return portfolio, w_mat
     else :
         print('defaulting to simple average')
         index_tmp = w_mat_predictors_list[0].index
