@@ -90,7 +90,7 @@ def generate_lo_slope_ma(lookback_windows, pente_windows, contravariants,):
 #                                     })
 #     return parameters
 
-def generate_fourier_wvt_decomposition(lookback_windows,contravariants,n_harms,fft_filter_types,wavelet_filters,dec_levels,thresholds):
+def generate_fourier_wvt_decomposition(lookback_windows,contravariants,n_harms,fft_filter_types,wavelet_filters,dec_levels,optimize_filtering_states, thresholds, soft_filtering_states):
     parameters = []
     for lookback_window in lookback_windows:
         for contravariant in contravariants:
@@ -99,16 +99,52 @@ def generate_fourier_wvt_decomposition(lookback_windows,contravariants,n_harms,f
                     for dec_level in dec_levels:
                         for filter_name in wavelet_filters:
                             for threshold in thresholds:
-                                    if n_harm < lookback_window:
-                                        parameters.append({
-                                            'lookback_window':lookback_window,
-                                            'contravariant':contravariant,
-                                            'fft_filter_type':fft_filter_type,
-                                            'n_harm':n_harm,
-                                            'filter_name':filter_name,
-                                            'dec_level':dec_level,
-                                            'threshold':threshold,
-                                        })
+                                for optimize_filtering in optimize_filtering_states:
+                                    for soft_filtering in soft_filtering_states:
+                                        if n_harm < lookback_window:
+                                            if optimize_filtering:
+                                                parameters.append({
+                                                    'lookback_window':lookback_window,
+                                                    'contravariant':contravariant,
+                                                    'fft_filter_type':fft_filter_type,
+                                                    'n_harm':n_harm,
+                                                    'filter_name':filter_name,
+                                                    'dec_level':dec_level,
+                                                    'threshold':threshold,
+                                                    'optimize_filtering':optimize_filtering,
+                                                    'soft_filtering':soft_filtering
+                                                })
+                                            else:
+                                                parameters.append({
+                                                    'lookback_window': lookback_window,
+                                                    'contravariant': contravariant,
+                                                    'fft_filter_type': fft_filter_type,
+                                                    'n_harm': n_harm,
+                                                    'filter_name': filter_name,
+                                                    'dec_level': dec_level,
+                                                    'optimize_filtering': optimize_filtering,
+                                                    'soft_filtering': soft_filtering
+                                                })
+
+    return parameters
+
+def generate_fourier_wvt_ortho_decomposition(lookback_windows,n_harms,fft_filter_types,wavelet_filters,dec_levels,coef_factors):
+    parameters = []
+    for lookback_window in lookback_windows:
+        for fft_filter_type in fft_filter_types:
+            for n_harm in n_harms:
+                for dec_level in dec_levels:
+                    for filter_name in wavelet_filters:
+                        for coeff_index_factor in coef_factors:
+                            if n_harm < lookback_window:
+                                parameters.append({
+                                    'lookback_window':lookback_window,
+                                    'fft_filter_type':fft_filter_type,
+                                    'n_harm':n_harm,
+                                    'filter_name':filter_name,
+                                    'dec_level':dec_level,
+                                    'coeff_index_factor':coeff_index_factor
+                                })
     return parameters
 
 def generate_kalman(lookback_windows,contravariants,n_harms,fft_filter_types,thresholds,obs_covs):
